@@ -40,75 +40,60 @@ qjackctlAboutForm::qjackctlAboutForm (
 	// Setup UI struct...
 	m_ui.setupUi(this);
 
-	// Stuff the about box...
-	QString sText = "<p align=\"center\"><br />\n";
-	sText += "<b>" + tr(QJACKCTL_SUBTITLE) + "</b><br />\n";
-	sText += "<br />\n";
-	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
-	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "<small><br />\n";
-#ifdef CONFIG_JACK_VERSION
-	sText += "<br />\n";
-	sText += tr("Using: JACK %1").arg(jack_get_version_string());
-	sText += "<br />\n";
-#endif
+	QStringList list;
 #ifdef CONFIG_DEBUG
-	sText += "<small><font color=\"red\">";
-	sText += tr("Debugging option enabled.");
-	sText += "</font></small><br />\n";
+	list << tr("Debugging option enabled.");
 #endif
 #ifndef CONFIG_SYSTEM_TRAY
-	sText += "<small><font color=\"red\">";
-	sText += tr("System tray disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("System tray disabled.");
 #endif
 #ifndef CONFIG_JACK_TRANSPORT
-	sText += "<small><font color=\"red\">";
-	sText += tr("Transport status control disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("Transport status control disabled.");
 #endif
 #ifndef CONFIG_JACK_REALTIME
-	sText += "<small><font color=\"red\">";
-	sText += tr("Realtime status disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("Realtime status disabled.");
 #endif
 #ifndef CONFIG_JACK_XRUN_DELAY
-	sText += "<small><font color=\"red\">";
-	sText += tr("XRUN delay status disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("XRUN delay status disabled.");
 #endif
 #ifndef CONFIG_JACK_MAX_DELAY
-	sText += "<small><font color=\"red\">";
-	sText += tr("Maximum delay status disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("Maximum delay status disabled.");
 #endif
 #ifndef CONFIG_JACK_PORT_ALIASES
-	sText += "<small><font color=\"red\">";
-	sText += tr("JACK Port aliases support disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("JACK Port aliases support disabled.");
 #endif
 #ifndef CONFIG_JACK_MIDI
-	sText += "<small><font color=\"red\">";
-	sText += tr("JACK MIDI support disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("JACK MIDI support disabled.");
 #endif
 #ifndef CONFIG_JACK_SESSION
-	sText += "<small><font color=\"red\">";
-	sText += tr("JACK Session support disabled.");
-	sText += "</font></small><br />";
+	list << tr("JACK Session support disabled.");
 #endif
 #ifndef CONFIG_ALSA_SEQ
 #if !defined(WIN32)
-	sText += "<small><font color=\"red\">";
-	sText += tr("ALSA/MIDI sequencer support disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("ALSA/MIDI sequencer support disabled.");
 #endif
 #endif
 #ifndef CONFIG_DBUS
 #if !defined(WIN32)
-	sText += "<small><font color=\"red\">";
-	sText += tr("D-Bus interface support disabled.");
-	sText += "</font></small><br />\n";
+	list << tr("D-Bus interface support disabled.");
 #endif
+#endif
+
+	// Stuff the about box...
+	QString sText = "<p align=\"center\"><br />\n";
+	sText += "<b>" QJACKCTL_TITLE " - " + tr(QJACKCTL_SUBTITLE) + "</b><br />\n";
+	sText += "<br />\n";
+	sText += tr("Version") + ": <b>" CONFIG_BUILD_VERSION "</b><br />\n";
+//	sText += "<small>" + tr("Build") + ": " CONFIG_BUILD_DATE "<small><br />\n";
+	if (!list.isEmpty()) {
+		sText += "<small><font color=\"red\">";
+		sText += list.join("<br />\n");
+		sText += "</font></small>";
+	}
+#ifdef CONFIG_JACK_VERSION
+	sText += "<br />\n";
+	sText += tr("Using: JACK %1").arg(jack_get_version_string());
+	sText += "<br />\n";
 #endif
 	sText += "<br />\n";
 	sText += tr("Website") + ": <a href=\"" QJACKCTL_WEBSITE "\">" QJACKCTL_WEBSITE "</a><br />\n";
